
Linux eduVPN client and Python API
==================================

This is the GNU/Linux desktop client and Python API for eduVPN.

Current status is BETA. There are various known and unknown bugs. Feel free to try the code out, but there could be some problems.

Read more about eduVPN on the eduVPN website http://eduvpn.org/.

Installation
============

Read the installation instructions [here](http://python-eduvpn-client.readthedocs.io/en/latest/introduction.html#installation).

Documentation
=============

You can find the documentation on [http://python-eduvpn-client.readthedocs.io](http://python-eduvpn-client.readthedocs.io).

Development
===========

[![Build Status](https://travis-ci.org/eduvpn/python-eduvpn-client.svg?branch=master)](https://travis-ci.org/eduvpn/python-eduvpn-client)
